This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Re: [Patch] Allow options.[ch] to be possibly regenerated after reconfigure--enable-languages=xxx


Err...  You're passing down only the pathname to move-if-change, but
you can't assume that whatever the Makefile understands as ${SHELL}
will be available in opts.sh's environment.  You'll see that SHELL is
often set in the environment to something that is not necessarily
Bourne-shell compatible.  Users of csh variants would experience
problems.  Please pass a single quoted argument, as I suggested, and
run that as move-if-change.

Sorry, I misunderstood. Is the fourth time the charm?


If so, could you please install?

Thanks for the review,
Kelley Cook

2003-07-09  Kelley Cook  <kelleycook@wideopenwest.com>

	* Makefile.in (options.h): Depend on Makefile.  Add in move-if-change
	to opts.sh command line.
	* opts.sh: Write to temporary files with a move-if-change at the end.

--- Makefile.in.orig	2003-07-09 08:12:27.000000000 -0400
+++ Makefile.in	2003-07-09 14:38:05.000000000 -0400
@@ -1416,9 +1416,10 @@
 
 options.c: $(lang_opt_files) $(srcdir)/opts.sh options.h intl.h
 
-options.h: $(lang_opt_files) $(srcdir)/opts.sh
-	AWK=$(AWK) $(SHELL) $(srcdir)/opts.sh options.c options.h \
-		$(lang_opt_files)
+options.h: $(lang_opt_files) $(srcdir)/opts.sh Makefile
+	AWK=$(AWK) $(SHELL) $(srcdir)/opts.sh \
+		'$(SHELL) $(srcdir)/move-if-change' \
+		options.c options.h $(lang_opt_files)
 
 dumpvers: dumpvers.c
 
--- opts.sh.orig	2003-07-08 01:25:39.000000000 -0400
+++ opts.sh	2003-07-09 14:33:10.000000000 -0400
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #
 # Usage: opts.sh outfile.c outfile.h file1.opt [file2.opt, ...]
 
 # Always operate in the C locale.
 LANG=C
@@ -30,8 +30,11 @@
 
 SORT=sort		# Could be /bin/sort or /usr/bin/sort
 
+MOVEIFCHANGE=$1; shift
 C_FILE=$1; shift
 H_FILE=$1; shift
+TMP_C_FILE=tmp-${C_FILE}
+TMP_H_FILE=tmp-${H_FILE}
 
 ${AWK} '
 	# Ignore comments and blank lines
@@ -88,13 +91,14 @@
 # Dump out an enumeration into a .h file, and an array of options into a
 # C file.  Combine the flags of duplicate options.
     END {
-	c_file = "'${C_FILE}'"
-	h_file = "'${H_FILE}'"
+	c_file = "'${TMP_C_FILE}'"
+	h_file = "'${TMP_H_FILE}'"
+	realh_file = "'${H_FILE}'"
 	comma = ","
 
 	print "/* This file is auto-generated by opts.sh.  */\n" > c_file
 	print "#include <intl.h>"			>> c_file
-	print "#include \"" h_file "\""			>> c_file
+	print "#include \"" realh_file "\""		>> c_file
 	print "#include \"opts.h\"\n"			>> c_file
 	print "const char * const lang_names[] =\n{"	>> c_file
 
@@ -163,3 +167,9 @@
 	print "};"					>> c_file
     }
 '
+
+# Copy the newly generated files back to the correct names only if different.
+# This is to prevent a cascade of file rebuilds when not necessary.
+
+${MOVEIFCHANGE} ${TMP_H_FILE} ${H_FILE}
+${MOVEIFCHANGE} ${TMP_C_FILE} ${C_FILE}
@@ -17,7 +17,7 @@
 # Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Usage: opts.sh outfile.c outfile.h file1.opt [file2.opt, ...]
+# Usage: opts.sh moveifchange outfile.c outfile.h file1.opt [file2.opt, ...]
 
 # Always operate in the C locale.

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]